@@ -7,9 +7,12 @@ use CFITSIO qw( :constants );
 use PDL;
 use Carp;
 
+require "check_status.pl";
+require "match_datatype.pl";
+
 CFITSIO::PerlyUnpacking(0);
 
-my ($fptr,$file,$status,$ycol,$i,$nrows,$anynul,$pdl);
+my ($fptr,$file,$status,$ycol,$i,$nrows,$pdl);
 
 $file = @ARGV ? shift : 'bintable.fits';
 
@@ -17,15 +20,13 @@ $file = @ARGV ? shift : 'bintable.fits';
 # open file, move to proper HDU
 #
 $fptr = CFITSIO::open_file($file,READONLY,$status);
-	check_status($status);
+check_status($status) or die;
 $fptr->movnam_hdu(ANY_HDU,'EVENTS',0,$status);
-	check_status($status);
 
 #
 # get number of rows in table
 #
 $fptr->get_num_rows($nrows,$status);
-	check_status($status);
 
 #
 # find out which column the Y event coordinates are stored in
@@ -38,24 +39,15 @@ $fptr->get_colnum(0,'Y',$ycol,$status);
 # make piddle, read data
 #
 $pdl = zeroes($nrows)->long;
-$fptr->read_col_lng($ycol,1,1,$nrows,0,${$pdl->get_dataref},$anynul,$status);
-	check_status($status);
+$fptr->read_col(match_datatype(long),$ycol,1,1,$nrows,0,${$pdl->get_dataref},undef,$status);
 $pdl->upd_data;
 
+$fptr->close_file($status);
+check_status($status) or die;
+
 #
 # create Y position histogram, plot data
 #
 my $hist = $pdl->hist($pdl->min,$pdl->max,1.0);
 my $y = $hist->sequence + $pdl->min;
 line $y, $hist;
-
-sub check_status {
-    my $status = shift;
-    my $errtxt;
-    if ($status) {
-      CFITSIO::fits_get_errstatus($status,$errtxt);
-	croak "$0: CFITSIO error, aborting...$errtxt";
-    }
-
-    return 1;
-}
