@@ -396,7 +396,7 @@ $extend = -99;
 print "\nRead back keywords:\n";
 
 CFITSIO::PerlyUnpacking(1);
-$fptr->read_imghdr(0,$simple,$bitpix,$naxis,$naxes,$pcount,$gcount,$extend,$status);
+$fptr->read_imghdr($simple,$bitpix,$naxis,$naxes,$pcount,$gcount,$extend,$status);
 CFITSIO::PerlyUnpacking(0);
 
 print "simple = $simple, bitpix = $bitpix, naxis = $naxis, naxes = ($naxes->[0], $naxes->[1])\n";
@@ -708,7 +708,7 @@ $fptr->write_tdim(3,$naxis,$naxes,$status);
 $naxis=0;
 $naxes=undef;
 CFITSIO::PerlyUnpacking(1);    # make naxes a normal Perl array
-$fptr->read_tdim(3,0,$naxis,$naxes,$status);
+$fptr->read_tdim(3,$naxis,$naxes,$status);
 CFITSIO::PerlyUnpacking(0);
 $fptr->read_key_str('TDIM3',$iskey,$comment,$status);
 print "TDIM3 = $iskey, $naxis, $naxes->[0], $naxes->[1], $naxes->[2]\n";
@@ -864,7 +864,7 @@ print "ffpcl_ status = $status\n";
 #  read data from ASCII table  #
 ################################
 
-$fptr->read_atblhdr(0,$rowlen,$nrows,$tfields,$ttype,${$tbcol->get_dataref},$tform,$tunit,$tblname,$status);
+$fptr->read_atblhdr($rowlen,$nrows,$tfields,$ttype,${$tbcol->get_dataref},$tform,$tunit,$tblname,$status);
 
 print "\nASCII table: rowlen, nrows, tfields, extname: $rowlen $nrows $tfields $tblname\n";
 for ($ii=0;$ii<$tfields;$ii++) {
@@ -1050,7 +1050,7 @@ print "HDU number = ${\($fptr->get_hdu_num($hdunum))}\n";
 $fptr->get_hdrspace($existkeys,$morekeys,$status);
 print "header contains $existkeys keywords with room for $morekeys more\n";
 
-$fptr->read_btblhdr(0,$nrows,$tfields,$ttype,$tform,$tunit,$binname,$pcount,$status);
+$fptr->read_btblhdr($nrows,$tfields,$ttype,$tform,$tunit,$binname,$pcount,$status);
 print "\nBinary table: nrows, tfields, extname, pcount: $nrows $tfields $binname $pcount\n";
 
 for ($ii=0;$ii<$tfields;$ii++) {
